@@ -71,8 +71,13 @@ copy_each_key_value (gpointer key, gpointer value, gpointer user_data)
 }
 
 static void
-parse_reference (GQuark type, const guchar *data, gsize n_data,
-                 GHashTable *headers, gpointer user_data)
+parse_reference (GQuark type,
+                 const guchar *data,
+                 gsize n_data,
+                 const gchar *outer,
+                 gsize n_outer,
+                 GHashTable *headers,
+                 gpointer user_data)
 {
 	Test *test = user_data;
 	gboolean res;
@@ -199,7 +204,6 @@ int
 main (int argc, char **argv)
 {
 	g_test_init (&argc, &argv, NULL);
-	egg_tests_chdir_base (argv[0]);
 
 	g_test_add ("/openssl/parse_reference", Test, NULL, setup, test_parse_reference, teardown);
 	g_test_add ("/openssl/write_reference", Test, NULL, setup, test_write_reference, teardown);
